==> aws-java-sdk-cognitoidp-1.10.71-sources.jar: com/amazonaws/services/cognitoidp/model/transform/UserPoolDescriptionTypeJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidp.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.cognitoidp.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * UserPoolDescriptionTypeMarshaller
 */
public class UserPoolDescriptionTypeJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(UserPoolDescriptionType userPoolDescriptionType,
            StructuredJsonGenerator jsonGenerator) {

        if (userPoolDescriptionType == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (userPoolDescriptionType.getId() != null) {
                jsonGenerator.writeFieldName("Id").writeValue(
                        userPoolDescriptionType.getId());
            }
            if (userPoolDescriptionType.getName() != null) {
                jsonGenerator.writeFieldName("Name").writeValue(
                        userPoolDescriptionType.getName());
            }
            if (userPoolDescriptionType.getLambdaConfig() != null) {
                jsonGenerator.writeFieldName("LambdaConfig");
                LambdaConfigTypeJsonMarshaller.getInstance().marshall(
                        userPoolDescriptionType.getLambdaConfig(),
                        jsonGenerator);
            }
            if (userPoolDescriptionType.getStatus() != null) {
                jsonGenerator.writeFieldName("Status").writeValue(
                        userPoolDescriptionType.getStatus());
            }
            if (userPoolDescriptionType.getLastModifiedDate() != null) {
                jsonGenerator.writeFieldName("LastModifiedDate").writeValue(
                        userPoolDescriptionType.getLastModifiedDate());
            }
            if (userPoolDescriptionType.getCreationDate() != null) {
                jsonGenerator.writeFieldName("CreationDate").writeValue(
                        userPoolDescriptionType.getCreationDate());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static UserPoolDescriptionTypeJsonMarshaller instance;

    public static UserPoolDescriptionTypeJsonMarshaller getInstance() {
        if (instance == null)
            instance = new UserPoolDescriptionTypeJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-cognitoidp-1.11.29-sources.jar: com/amazonaws/services/cognitoidp/model/transform/UserPoolDescriptionTypeJsonMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.cognitoidp.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.cognitoidp.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * UserPoolDescriptionTypeMarshaller
 */
public class UserPoolDescriptionTypeJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(UserPoolDescriptionType userPoolDescriptionType,
            StructuredJsonGenerator jsonGenerator) {

        if (userPoolDescriptionType == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (userPoolDescriptionType.getId() != null) {
                jsonGenerator.writeFieldName("Id").writeValue(
                        userPoolDescriptionType.getId());
            }
            if (userPoolDescriptionType.getName() != null) {
                jsonGenerator.writeFieldName("Name").writeValue(
                        userPoolDescriptionType.getName());
            }
            if (userPoolDescriptionType.getLambdaConfig() != null) {
                jsonGenerator.writeFieldName("LambdaConfig");
                LambdaConfigTypeJsonMarshaller.getInstance().marshall(
                        userPoolDescriptionType.getLambdaConfig(),
                        jsonGenerator);
            }
            if (userPoolDescriptionType.getStatus() != null) {
                jsonGenerator.writeFieldName("Status").writeValue(
                        userPoolDescriptionType.getStatus());
            }
            if (userPoolDescriptionType.getLastModifiedDate() != null) {
                jsonGenerator.writeFieldName("LastModifiedDate").writeValue(
                        userPoolDescriptionType.getLastModifiedDate());
            }
            if (userPoolDescriptionType.getCreationDate() != null) {
                jsonGenerator.writeFieldName("CreationDate").writeValue(
                        userPoolDescriptionType.getCreationDate());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static UserPoolDescriptionTypeJsonMarshaller instance;

    public static UserPoolDescriptionTypeJsonMarshaller getInstance() {
        if (instance == null)
            instance = new UserPoolDescriptionTypeJsonMarshaller();
        return instance;
    }

}
